## cmake toolchain

This cmake toolchain files are copied and modified from a project called *QMLApplicationTemplate*. 
Please have a look at their project for more details:

https://github.com/qCring/QMLApplicationTemplate/tree/master/cmake